@@ -448,9 +448,11 @@ ipc_recv_path(char *buf)
 		/*
 		 * Receive one single message blocking for it.
 		 */
-		rc = msgrcv(msgid, &msg, sizeof(msg), 0, 0);
+		rc = msgrcv(msgid, &msg, sizeof(msg), 0, IPC_NOWAIT);
 		if (rc < 0)
 		{
+			if (errno == ENOMSG)
+				return -2;
 			if (errno == EINTR)
 				continue;
 
